# urlshrink
an open source python based url shortener
- [X] sqlite database
- [X] hashids 
- [X] redirection
- [X] hit counting
- [X] copy buttons
- [X] delete button
- [X] qr codes
- [X] options
  - [X] key / password or public deletable
  - [X] gets destroyed after x timeunits
- [X] db cleansing after X days so the hashids don't get too long
- [ ] statistics
- [ ] cli client
- [ ] also accept torrent, ftp, ssh, etc. urls
- [ ] sharing via platforms
- [ ] api for android app